@@ -12,7 +12,7 @@ class PubSubCommandsMixin:
         super(PubSubCommandsMixin, self).__init__(*args, **kwargs)
         self._pubsub = 0  # Count of subscriptions
         self._server: Any
-        self.version: Tuple[int]
+        self.version: Tuple[int, ...]
 
     def _subscribe(self, channels: Iterable[bytes], subscribers: Dict[bytes, Any], mtype: bytes) -> NoResponse:
         for channel in channels:
@@ -140,16 +140,16 @@ class PubSubCommandsMixin:
             help_strings = [
                 "PUBSUB <subcommand> [<arg> [value] [opt] ...]. Subcommands are:",
                 "CHANNELS [<pattern>]",
-                "    Return the currently active channels matching a <pattern> (default: '*')" ".",
+                "    Return the currently active channels matching a <pattern> (default: '*').",
                 "NUMPAT",
                 "    Return number of subscriptions to patterns.",
                 "NUMSUB [<channel> ...]",
                 "    Return the number of subscribers for the specified channels, excluding",
                 "    pattern subscriptions(default: no channels).",
                 "SHARDCHANNELS [<pattern>]",
-                "    Return the currently active shard level channels matching a <pattern> (d" "efault: '*').",
+                "    Return the currently active shard level channels matching a <pattern> (default: '*').",
                 "SHARDNUMSUB [<shardchannel> ...]",
-                "    Return the number of subscribers for the specified shard level channel(s" ")",
+                "    Return the number of subscribers for the specified shard level channel(s)",
                 "HELP",
                 ("    Prints this help." if self.version < (7, 1) else "    Print this help."),
             ]
@@ -157,7 +157,7 @@ class PubSubCommandsMixin:
             help_strings = [
                 "PUBSUB <subcommand> [<arg> [value] [opt] ...]. Subcommands are:",
                 "CHANNELS [<pattern>]",
-                "    Return the currently active channels matching a <pattern> (default: '*')" ".",
+                "    Return the currently active channels matching a <pattern> (default: '*').",
                 "NUMPAT",
                 "    Return number of subscriptions to patterns.",
                 "NUMSUB [<channel> ...]",
